# Table of Contents

- [graphql-basics](<./graphql-basics.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [GraphQL Basics](<./GraphQL-Basics.md>)
  - [Queries](<./GraphQL-Basics/Queries.md>)
  - [Mutations](<./GraphQL-Basics/Mutations.md>)
  - [Including Multiple Mutations in a Single Request Using Aliases](<./GraphQL-Basics/Including-Multiple-Mutations-in-a-Single-Request-Using-Aliases.md>)
  - [Retrieving a List of Filtering Facet Keys](<./GraphQL-Basics/Retrieving-a-List-of-Filtering-Facet-Keys.md>)
  - [Pagination in GraphQL](<./GraphQL-Basics/Pagination-in-GraphQL.md>)
  - [Was this page helpful?](<./GraphQL-Basics/Was-this-page-helpful.md>)
